'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);

  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }

  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var GMAPS_API_URL = 'https://maps.googleapis.com';
var GMAPS_API_SRC_URL = GMAPS_API_URL + "/maps/api/js";
var GMAPS_SCRIPT_SELECTOR = "script[src^=\"" + GMAPS_API_URL + "\"]";

function getAllGmapsScript() {
  var _document;

  return (_document = document) == null ? void 0 : _document.querySelectorAll(GMAPS_SCRIPT_SELECTOR);
}

function removeExistingGmapsAPIScript(callback) {
  var scripts = getAllGmapsScript();

  if (scripts.length > 0) {
    scripts.forEach(function (script) {
      return script.remove();
    });
    callback();
  }
}

function deleteGmapsInstance(google) {
  if (google) {
    delete google.maps;
  }
}

function createGmapsScriptElement(_ref) {
  var apiKey = _ref.apiKey,
      region = _ref.region,
      language = _ref.language,
      libraries = _ref.libraries;
  deleteGmapsInstance(window.google);
  var script = document.createElement('script');
  script.async = true;
  var urlSearchParams = new URLSearchParams({
    key: apiKey,
    w: 'weekly',
    region: region,
    language: language,
    libraries: libraries.sort().join(','),
    loading: 'async',
    callback: 'initMap'
  });
  Object.assign(script, {
    id: 'googlemaps',
    type: 'text/javascript',
    defer: true,
    async: true,
    src: GMAPS_API_SRC_URL + "?" + urlSearchParams.toString()
  });
  document.head.appendChild(script);
}

var scriptHandler = {
  getAllGmapsScript: getAllGmapsScript,
  removeExistingGmapsAPIScript: removeExistingGmapsAPIScript,
  deleteGmapsInstance: deleteGmapsInstance,
  createGmapsScriptElement: createGmapsScriptElement
};

var originalConsoleWarn = console.warn;
var useScriptLoader = function useScriptLoader(_ref) {
  var apiKey = _ref.apiKey,
      initMap = _ref.initMap,
      libraries = _ref.libraries;
  var isLoading = react.useRef(false);
  react.useEffect(function () {
    window.initMap = initMap;
  }, [initMap]);
  var warnCount = react.useRef(0);
  var suppressedConsoleWarn = react.useCallback(function () {
    warnCount.current++;

    if (warnCount.current > 1) {
      console.warn = originalConsoleWarn;
      warnCount.current = 0;
    }
  }, []);
  var observeScript = react.useCallback(function () {
    var observer = new MutationObserver(function (mutationsList, observer) {
      for (var _iterator = _createForOfIteratorHelperLoose(mutationsList), _step; !(_step = _iterator()).done;) {
        var mutation = _step.value;
        var scripts = scriptHandler.getAllGmapsScript();

        if (mutation.type === 'childList' && (scripts == null ? void 0 : scripts.length) > 1) {
          isLoading.current = false;
          observer.disconnect();
        }
      }
    });
    observer.observe(document.head, {
      childList: true,
      subtree: true
    });
  }, []);
  var loadScript = react.useCallback(function (language, region) {
    if (isLoading.current) return;
    isLoading.current = true;
    scriptHandler.removeExistingGmapsAPIScript(function () {
      console.warn = suppressedConsoleWarn;
    });
    scriptHandler.createGmapsScriptElement({
      apiKey: apiKey,
      region: region,
      language: language,
      libraries: libraries
    });
    observeScript();
  }, [apiKey, libraries, observeScript, suppressedConsoleWarn]);
  return {
    loadScript: loadScript,
    isLoading: isLoading
  };
};

exports.useScriptLoader = useScriptLoader;
//# sourceMappingURL=gmaps-script-loader.cjs.development.js.map
